# setwd("C:\\Users\\marjan\\Documents\\FDV\\MVA2018_19\\Vaje 5")

library("MASS")
library("blockmodeling")
# nalozimo se lastne funkcije
source("../UcbenikR-funkcije.R")
source("../LDAandCChelperFunctions.R")
#######################################################################################
#                            PRIPRAVA PODATKOV
#######################################################################################
# uvoz podatkov
load("../WVSLO_rekodirane", verbose = TRUE)

usmerjenost_vase <- c("V70", "V71", "V73", "V75", "V76")
usmerjenost_ven  <- c("V72", "V74", "V77", "V78", "V79")
Sch <- c(usmerjenost_vase, usmerjenost_ven)
kratka.imena.list <- list("V70" = "ustvarjanost",
                          "V71" = "bogastvo",
                          "V73" = "zabava",
                          "V75" = "uspesnost",
                          "V76" = "pustolovstvo",
                          "V72" = "varnost",
                          "V74" = "dobrodelnost",
                          "V77" = "sprejemljivost",
                          "V78" = "naravovarstvenost",
                          "V79" = "konzervatizem")
levo_desno <- paste0("V", 96:99)
podatki$V96 <- car::recode(podatki$V96, "1 = 10; 2 = 9; 3 = 8; 4 = 7; 5 = 6; 6 = 5; 7 = 4; 8 = 3; 9 = 2; 10 = 1")
podatki$V98 <- car::recode(podatki$V98, "1 = 10; 2 = 9; 3 = 8; 4 = 7; 5 = 6; 6 = 5; 7 = 4; 8 = 3; 9 = 2; 10 = 1")

# uporabljali bomo samo enote, ki imajo vrednosti pri vseh spremenljivkah
com <- complete.cases(podatki[, c(Sch, levo_desno)])
schData <- podatki[com, c(Sch, levo_desno)]
varLabs <- attributes(podatki)$variable.labels
#######################################################################################
#                            KANONICNE KORELACIJE
#######################################################################################
# pogledamo korelacijsko matriko
plot.mat(cor(schData), main = "")
# izracunamo kanonicno resitev (linearne kombinacije in korelacije)
# na standardiziranih podatkih
ccRes <- ccPlus(X = scale(schData[, Sch]), Y = scale(schData[, levo_desno]))
# pogledamo lastne vrednosti, delez pojasnjene variabilnosti, kanonicne korelacije in vrednost mere prekrivanja sklopov
ccRes$eigModel
# preverimo, katere korelacije so statisticno znacilno razlicne od 0 
# (pri doloceni stopnji statisticne znacilnosti)
round(ccRes$sigTest, 3)

# pogledamo regresijske koeficiente za kanonicno spremenljivko prve mnozice spremenljivk
# resitve za samo prve stiri statisticno znacilne korelacije
rownames(ccRes$xcoef) <- kratka.imena.list[rownames(ccRes$xcoef)]
plot.mat(ccRes$xcoef[, 1:4], mar = c(5, 2, 2, 2))

# pogledamo regresijske koeficiente za kanonicno spremenljivko druge mnozice spremenljivk
# resitve za samo prve stiri statisticno znacilne korelacije
rownames(ccRes$ycoef) <- varLabs[rownames(ccRes$ycoef)]
plot.mat(ccRes$ycoef[, 1:4], mar = c(5, 15, 2, 2), main = "")

# pogledamo korelacije med vrednostmi kanonicnih spremenljivk (prve mnozice spremenljivk) in spremenljivk
rownames(ccRes$scores$corr.X.xscores) <- kratka.imena.list[rownames(ccRes$scores$corr.X.xscores)]
plot.mat(ccRes$scores$corr.X.xscores, mar = c(5, 2, 2, 2), main = "")

# pogledamo korelacije med vrednostmi kanonicnih spremenljivk (druge mnozice spremenljivk) in spremenljivk
rownames(ccRes$scores$corr.Y.yscores) <- varLabs[rownames(ccRes$scores$corr.Y.yscores)]
plot.mat(ccRes$scores$corr.Y.yscores, mar = c(5, 15, 2, 2), main = "")

# narisemo resitev na eni sliki
par(mfrow=c(2, 1))
plot.mat(ccRes$xcoef[, 1:2], mar=c(5, 2, 2, 2), main="vrednote", title.line = 1, printMultipliedMessage = FALSE)
plot.mat(ccRes$ycoef[, 1:2], mar=c(5, 12, 2, 2), main="politicna usmerjenost", title.line = 1, printMultipliedMessage = FALSE)
text(y = 1.5, x = (0:1), labels = round(ccRes$cor[1:2], 2))
text(y = 1.5, x = -2, labels = "Kanonicna korelacija: ")

# povprecen delez pojasnjene variabilnosti sklopa vsebinskih spremenljivk s kanonicnimi spremenljivkami
# (s kanonicnimi spremenljivkami pojasnimo Xx variabilnosti originalnih spremenljivk)
Xx <- cbind(as.matrix(round(apply(ccRes$scores$corr.X.xscores^2, 2, mean), 3)), 
      cumsum(round(apply(ccRes$scores$corr.X.xscores^2, 2, mean), 3)))
rownames(Xx) <- paste0("Kanonicna spremenljivka ", 1:4, ":")
colnames(Xx) <- c("R2", "cum R2")
Xx

Yy <- cbind(as.matrix(round(apply(ccRes$scores$corr.Y.yscores^2, 2, mean), 3)), 
            cumsum(round(apply(ccRes$scores$corr.Y.yscores^2, 2, mean), 3)))
rownames(Yy) <- paste0("Kanonicna spremenljivka ", 1:4, ":")
colnames(Yy) <- c("R2", "cum R2")
Yy
# v primeru, ko imata sklopa vsebinskih spremenljivk razlicno stevilo spremenljivk, 
# kanonicne spremenljivke sklopa, ki ima manj spremenljivk,
# pojasnijo vso variabilnost vsebinskih spremenljivk tega sklopa

# povprecen delez pojasnjene variabilnosti sklopa vsebinskih spremenljivk s kanonicnimi spremenljivkami iz drugega sklopa
Yx <- cbind(as.matrix(round(apply(ccRes$scores$corr.Y.xscores^2, 2, mean), 3)), 
            cumsum(round(apply(ccRes$scores$corr.Y.xscores^2, 2, mean), 3)))
rownames(Yx) <- paste0("Kanonicna spremenljivka ", 1:4, ":")
colnames(Yx) <- c("R2", "cum R2")
Yx

Xy <- cbind(as.matrix(round(apply(ccRes$scores$corr.X.yscores^2, 2, mean), 3)), 
            cumsum(round(apply(ccRes$scores$corr.X.yscores^2, 2, mean), 3)))
rownames(Xy) <- paste0("Kanonicna spremenljivka ", 1:4, ":")
colnames(Xy) <- c("R2", "cum R2")
Xy
# vsaka nadaljna kanonicna spremenljivka pojasni manj varibilnosti "vsebinskih" spremenljivk drugega sklopa

